[rhythmbox] gtk-doc updates



commit 2e01d1daae6dd54cb0846ba7110631fe929bb0d2
Author: Jonathan Matthew <jonathan d14n org>
Date:   Mon Aug 2 22:33:50 2010 +1000

    gtk-doc updates
    
    Fix a variety of doc errors (misspellings, miscapitalisations, etc.),
    ignore a lot of headers for things that aren't part of the API, and
    add the new RhythmDBEntryType.

 backends/rb-player.c                   |   15 ++++++++
 doc/reference/Makefile.am              |   63 +++++++++++++++++++++++++++++++-
 doc/reference/rhythmbox-docs.sgml      |    1 +
 doc/reference/rhythmbox-sections.txt   |   52 ++++++++++++++------------
 doc/reference/rhythmbox.types          |    2 +
 lib/libmediaplayerid/mpid-util.c       |    3 +-
 lib/rb-text-helpers.c                  |    4 +-
 lib/rb-util.c                          |    2 +-
 plugins/status-icon/rb-tray-icon-gtk.c |    2 +-
 rhythmdb/rhythmdb-query.c              |    4 +-
 rhythmdb/rhythmdb.c                    |   12 +++---
 shell/rb-play-order-random.h           |    7 +++-
 shell/rb-shell.c                       |    6 ++--
 sources/rb-auto-playlist-source.c      |    2 +-
 sources/rb-browser-source.c            |    2 +-
 sources/rb-library-source.c            |    4 +-
 sources/rb-missing-files-source.c      |    2 +-
 sources/rb-podcast-source.c            |    6 ++--
 widgets/rb-entry-view.c                |    4 ++-
 widgets/rb-property-view.c             |    2 +-
 20 files changed, 142 insertions(+), 53 deletions(-)
---
diff --git a/backends/rb-player.c b/backends/rb-player.c
index 5dcb86a..fc10c4f 100644
--- a/backends/rb-player.c
+++ b/backends/rb-player.c
@@ -33,6 +33,21 @@
 #include "rb-player-gst-xfade.h"
 #include "rb-marshal.h"
 
+/**
+ * RBPlayerPlayType:
+ * @RB_PLAYER_PLAY_REPLACE: Replace the existing stream
+ * @RB_PLAYER_PLAY_AFTER_EOS: Start the new stream after the current stream ends
+ * @RB_PLAYER_PLAY_CROSSFADE: Crossfade between the existing stream and the new stream
+ */
+
+/**
+ * RBPlayerError:
+ * @RB_PLAYER_ERROR_NO_AUDIO: Audio playback not available
+ * @RB_PLAYER_ERROR_GENERAL: Nonspecific error
+ * @RB_PLAYER_ERROR_INTERNAL: Internal error
+ * @RB_PLAYER_ERROR_NOT_FOUND: The resource could not be found
+ */
+
 /* Signals */
 enum {
 	EOS,
diff --git a/doc/reference/Makefile.am b/doc/reference/Makefile.am
index a76394d..dee3bd4 100644
--- a/doc/reference/Makefile.am
+++ b/doc/reference/Makefile.am
@@ -28,6 +28,9 @@ HFILE_GLOB=$(top_srcdir)/lib/*.h
 CFILE_GLOB=$(top_srcdir)/lib/*.c
 
 # Header files to ignore when scanning.
+# - imported code
+# - generated code
+# - plugins (no API there)
 IGNORE_HFILES= \
 	config.h \
 	eel-gconf-extensions.h \
@@ -46,14 +49,34 @@ IGNORE_HFILES= \
 	rb-shell-player-glue.h \
 	rb-shell-player-binding.h \
 	rb-playlist-manager-glue.h \
+	rb-play-order-linear.h \
+	rb-play-order-linear-loop.h \
+	rb-play-order-queue.h \
+	rb-play-order-random-by-age-and-rating.h \
+	rb-play-order-random-by-age.h \
+	rb-play-order-random-by-rating.h \
+	rb-play-order-random-equal-weights.h \
+	rb-play-order-shuffle.h \
 	\
 	npapi.h \
 	npruntime.h \
 	npupp.h \
+	rb-feed-podcast-properties-dialog.h \
+	rb-podcast-manager.h \
+	rb-podcast-parse.h \
+	rb-podcast-properties-dialog.h \
+	rb-podcast-source.h \
 	\
 	gossip-cell-renderer-expander.h \
 	rb-query-creator-private.h \
 	\
+	rb-playlist-xml.h \
+	rb-sync-settings.h \
+	rb-sync-settings-ui.h \
+	rb-sync-state.h \
+	rb-sync-state-ui.h \
+	\
+	rb-audiocd-source.h \
 	sj-error.h \
 	sj-metadata-getter.h \
 	sj-metadata-gvfs.h \
@@ -61,7 +84,45 @@ IGNORE_HFILES= \
 	sj-metadata-musicbrainz.h \
 	sj-metadata-musicbrainz3.h \
 	sj-metadata.h \
-	sj-structures.h
+	sj-structures.h \
+	rb-audioscrobbler-entry.h \
+	rb-lastfm-play-order.h \
+	rb-audioscrobbler.h \
+	rb-lastfm-source.h \
+	rb-recorder.h \
+	rb-playlist-source-recorder.h \
+	rb-daap-record.h \
+	rb-rhythmdb-query-model-dmap-db-adapter.h \
+	rb-dmap-container-db-adapter.h \
+	rb-daap-dialog.h \
+	rb-rhythmdb-dmap-db-adapter.h \
+	rb-daap-glue.h \
+	rb-daap-src.h \
+	rb-daap-plugin.h \
+	rb-daap-source.h \
+	rb-daap-sharing.h \
+	rb-daap-record-factory.h \
+	rb-daap-container-record.h \
+	rb-fm-radio-source.h \
+	rb-radio-tuner.h \
+	rb-psp-source.h \
+	rb-generic-player-source.h \
+	rb-generic-player-playlist-source.h \
+	rb-nokia770-source.h \
+	rb-ipod-static-playlist-source.h \
+	rb-ipod-source.h \
+	rb-ipod-helpers.h \
+	rb-ipod-db.h \
+	rb-station-properties-dialog.h \
+	rb-iradio-source-search.h \
+	rb-iradio-source.h \
+	rb-mtp-thread.h \
+	rb-mtp-source.h \
+	rb-static-icon-plugin.h \
+	rb-tray-icon-gtk.h \
+	rb-vis-widget.h
+
+
 
 
 
diff --git a/doc/reference/rhythmbox-docs.sgml b/doc/reference/rhythmbox-docs.sgml
index ec15705..b9e107e 100644
--- a/doc/reference/rhythmbox-docs.sgml
+++ b/doc/reference/rhythmbox-docs.sgml
@@ -35,6 +35,7 @@
 
 	<chapter>  	
 		<title>RhythmDB</title>
+		<xi:include href="xml/rhythmdb-entry-type.xml"/>
 		<xi:include href="xml/rhythmdb-import-job.xml"/>
 		<xi:include href="xml/rhythmdb-property-model.xml"/>
 		<xi:include href="xml/rhythmdb-query-model.xml"/>
diff --git a/doc/reference/rhythmbox-sections.txt b/doc/reference/rhythmbox-sections.txt
index f6d3c8b..0bc8b6f 100644
--- a/doc/reference/rhythmbox-sections.txt
+++ b/doc/reference/rhythmbox-sections.txt
@@ -225,7 +225,6 @@ RBStatusbar
 RBStatusbarClass
 rb_statusbar_new
 rb_statusbar_set_source
-rb_statusbar_set_progress
 <SUBSECTION Standard>
 RB_STATUSBAR
 RB_IS_STATUSBAR
@@ -533,6 +532,7 @@ RB_TYPE_SOURCE_EOF_TYPE
 <TITLE>RBPlayer</TITLE>
 RBPlayer
 RBPlayerIface
+RBPlayerPlayType
 RBPlayerError
 rb_player_new
 rb_player_open
@@ -632,19 +632,7 @@ RhythmDBQueryModelPrivate
 <TITLE>RhythmDB</TITLE>
 RhythmDB
 RhythmDBEntry
-RhythmDBEntryActionFunc
-RhythmDBEntryStringFunc
-RhythmDBEntryCanSyncFunc
-RhythmDBEntrySyncFunc
-RhythmDBEntryCategory
-RhythmDBEntryType
 RhythmDBQuery
-RHYTHMDB_ENTRY_TYPE_SONG
-RHYTHMDB_ENTRY_TYPE_PODCAST_POST
-RHYTHMDB_ENTRY_TYPE_PODCAST_FEED
-RHYTHMDB_ENTRY_TYPE_IMPORT_ERROR
-RHYTHMDB_ENTRY_TYPE_IGNORE
-RHYTHMDB_ENTRY_TYPE_INVALID
 RhythmDBQueryType
 RhythmDBPropType
 RHYTHMDB_PROP_STREAM_SONG_TITLE
@@ -659,7 +647,7 @@ rhythmdb_entry_get_boolean
 rhythmdb_entry_get_uint64
 rhythmdb_entry_get_ulong
 rhythmdb_entry_get_double
-rhythmdb_entry_get_pointer
+rhythmdb_entry_get_object
 rhythmdb_entry_get_entry_type
 RhythmDBError
 rhythmdb_new
@@ -669,14 +657,12 @@ rhythmdb_save
 rhythmdb_save_async
 rhythmdb_start_action_thread
 rhythmdb_commit
-rhythmdb_entry_is_editable
 rhythmdb_entry_new
 rhythmdb_entry_example_new
 rhythmdb_add_uri
 rhythmdb_add_uri_with_types
 rhythmdb_entry_get
 rhythmdb_entry_set
-rhythmdb_entry_get_playback_uri
 rhythmdb_entry_get_type_data
 RHYTHMDB_ENTRY_GET_TYPE_DATA
 rhythmdb_entry_delete
@@ -716,7 +702,7 @@ rhythmdb_entry_gather_metadata
 rhythmdb_emit_entry_extra_metadata_notify
 rhythmdb_is_busy
 rhythmdb_compute_status_normal
-rhythmdb_entry_register_type
+rhythmdb_register_entry_type
 rhythmdb_entry_type_get_by_name
 rhythmdb_get_property_type
 rhythmdb_entry_ref
@@ -752,11 +738,29 @@ rhythmdb_get_type
 RhythmDBPrivate
 rhythmdb_emit_entry_added
 rhythmdb_emit_entry_deleted
-rhythmdb_entry_song_get_type
-rhythmdb_entry_podcast_post_get_type
-rhythmdb_entry_podcast_feed_get_type
-rhythmdb_entry_import_error_get_type
-rhythmdb_entry_ignore_get_type
+</SECTION>
+
+<SECTION>
+<FILE>rhythmdb-entry-type</FILE>
+<TITLE>RhythmDBEntryType</TITLE>
+RhythmDBEntryCategory
+RhythmDBEntryType
+RhythmDBEntryTypeClass
+rhythmdb_entry_type_get_name
+rhythmdb_entry_get_playback_uri
+rhythmdb_entry_created
+rhythmdb_entry_pre_destroy
+rhythmdb_entry_can_sync_metadata
+rhythmdb_entry_sync_metadata
+<SUBSECTION Standard>
+RHYTHMDB_ENTRY_TYPE_SONG
+RHYTHMDB_ENTRY_TYPE_IMPORT_ERROR
+RHYTHMDB_ENTRY_TYPE_IGNORE
+rhythmdb_get_song_entry_type
+rhythmdb_get_error_entry_type
+rhythmdb_get_ignore_entry_type
+RhythmDBEntryTypePrivate
+rhythmdb_entry_type_get_type
 </SECTION>
 
 <SECTION>
@@ -1528,8 +1532,8 @@ RBTrackTransferBatch
 RBTrackTransferBatchClass
 rb_track_transfer_batch_new
 rb_track_transfer_batch_add
-rb_track_transfer_batch_start
-rb_track_transfer_batch_next
+rb_track_transfer_batch_check_media_types
+rb_track_transfer_batch_cancel
 <SUBSECTION Standard>
 rb_track_transfer_batch_get_type
 RB_TYPE_TRACK_TRANSFER_BATCH
diff --git a/doc/reference/rhythmbox.types b/doc/reference/rhythmbox.types
index 08bf899..ea901bd 100644
--- a/doc/reference/rhythmbox.types
+++ b/doc/reference/rhythmbox.types
@@ -68,6 +68,8 @@
 #include "rhythmdb-query-model.h"
 #include "rhythmdb-tree.h"
 #include "rhythmdb-import-job.h"
+#include "rhythmdb-entry.h"
+#include "rhythmdb-entry-type.h"
 
 rb_auto_playlist_source_get_type
 rb_browser_source_get_type
diff --git a/lib/libmediaplayerid/mpid-util.c b/lib/libmediaplayerid/mpid-util.c
index a50a029..7e70774 100644
--- a/lib/libmediaplayerid/mpid-util.c
+++ b/lib/libmediaplayerid/mpid-util.c
@@ -31,10 +31,10 @@ static gboolean debug_enabled = FALSE;
 
 /**
  * MPIDError:
- *
  * @MPID_ERROR_NONE: Indicates no error has occurred
  * @MPID_ERROR_NO_DEVICE_PATH: Unable to find the device path
  * @MPID_ERROR_MECHANISM_FAILED: The device detection mechanism (e.g. udev or HAL) failed
+ * @MPID_ERROR_NOT_MEDIA_PLAYER: The device is not a media player
  * @MPID_ERROR_DEVICE_INFO_MISSING: The device detection mechanism identified the device
  *   but was unable to locate its device information
  */
@@ -62,7 +62,6 @@ mpid_error_get_type (void)
 
 /**
  * MPIDSource:
- *
  * @MPID_SOURCE_NONE: No device information is available
  * @MPID_SOURCE_SYSTEM: Device information provided by the operating system (e.g. udev or HAL)
  * @MPID_SOURCE_OVERRIDE: Device information provided by an override file on the device itself.
diff --git a/lib/rb-text-helpers.c b/lib/rb-text-helpers.c
index 40d3846..be0b4d5 100644
--- a/lib/rb-text-helpers.c
+++ b/lib/rb-text-helpers.c
@@ -156,7 +156,7 @@ rb_text_common_direction (const char *first, ...)
  *
  * 1. Caller supplies the base direction of the result in base_dir.
  *
- * 2. Insert either %LRM or %RLM at the beginning of the string to set
+ * 2. Insert either LRM or RLM at the beginning of the string to set
  *    its base direction, according to base_dir.
  *
  * 3. Find the direction of each string using pango.
@@ -165,7 +165,7 @@ rb_text_common_direction (const char *first, ...)
  *    just insert them in.
  *
  * 5. For strings that have the opposite direction than the base one,
- *    insert them surrounded with embedding codes %RLE/%LRE .. %PDF.
+ *    insert them surrounded with embedding codes RLE/LRE .. PDF.
  *
  * Return value: a new string containing the result.
  */
diff --git a/lib/rb-util.c b/lib/rb-util.c
index 2d437a3..b8a3e3b 100644
--- a/lib/rb-util.c
+++ b/lib/rb-util.c
@@ -265,7 +265,7 @@ rb_gvalue_compare (GValue *a, GValue *b)
  * @a: left hand side
  * @b: right hand size
  *
- * Compares two #GTimeval structures for sorting.
+ * Compares two #GTimeVal structures for sorting.
  *
  * Return value: -1 if @a < @b, 0 if @a == @b, 1 if @a > @b
  */
diff --git a/plugins/status-icon/rb-tray-icon-gtk.c b/plugins/status-icon/rb-tray-icon-gtk.c
index eb68aa8..e44055f 100644
--- a/plugins/status-icon/rb-tray-icon-gtk.c
+++ b/plugins/status-icon/rb-tray-icon-gtk.c
@@ -43,7 +43,7 @@
 
 
 
-/**
+/*
  * SECTION:rb-tray-icon
  * @short_description: Notification area icon
  *
diff --git a/rhythmdb/rhythmdb-query.c b/rhythmdb/rhythmdb-query.c
index 719ea95..24d8f4f 100644
--- a/rhythmdb/rhythmdb-query.c
+++ b/rhythmdb/rhythmdb-query.c
@@ -706,7 +706,7 @@ rhythmdb_query_deserialize (RhythmDB *db, xmlNodePtr parent)
 	return query;
 }
 
-/**
+/*
  * This is used to "process" queries, before using them. It is mainly used to two things:
  *
  * 1) performing expensive data transformations once per query, rather than
@@ -714,7 +714,7 @@ rhythmdb_query_deserialize (RhythmDB *db, xmlNodePtr parent)
  *
  * 2) defining criteria in terms of other lower-level ones that the db backend
  *    actually implements. e.g. RHYTHMDB_QUERY_YEAR_*
- **/
+ */
 
 /**
  * rhythmdb_query_preprocess:
diff --git a/shell/rb-play-order-random.h b/shell/rb-play-order-random.h
index 20542af..b2260ce 100644
--- a/shell/rb-play-order-random.h
+++ b/shell/rb-play-order-random.h
@@ -58,9 +58,14 @@ struct _RBRandomPlayOrderClass
 	RBPlayOrderClass parent_class;
 
 	/**
+	 * get_entry_weight:
+	 * @rorder: the play order
+	 * @db: the #RhythmDB
+	 * @entry: the #RhythmDBEntry to weight
+	 *
 	 * This method should return a weight for the given @entry.
 	 *
-	 * The @db will be locked when this method is called.
+	 * Return value: weighting for @entry
 	 */
 	double (*get_entry_weight) (RBRandomPlayOrder *rorder, RhythmDB *db, RhythmDBEntry *entry);
 };
diff --git a/sources/rb-auto-playlist-source.c b/sources/rb-auto-playlist-source.c
index fc237c5..b724fc7 100644
--- a/sources/rb-auto-playlist-source.c
+++ b/sources/rb-auto-playlist-source.c
@@ -860,7 +860,7 @@ rb_auto_playlist_source_set_query (RBAutoPlaylistSource *source,
  * @limit_type: returns the playlist limit type
  * @limit_value: returns the playlist limit value
  * @sort_key: returns the playlist sorting key
- * @sort_order: returns the playlist sorting direction (as a GtkSortOrder)
+ * @sort_order: returns the playlist sorting direction (as a #GtkSortType)
  *
  * Extracts the current query, playlist limit, and sorting settings for the playlist.
  */
diff --git a/sources/rb-browser-source.c b/sources/rb-browser-source.c
index b0cbf86..a31609a 100644
--- a/sources/rb-browser-source.c
+++ b/sources/rb-browser-source.c
@@ -822,7 +822,7 @@ rb_browser_source_get_paned_key (RBBrowserSource *source)
 
 /**
  * rb_browser_source_has_drop_support:
- * @source: a #RBBrowser
+ * @source: a #RBBrowserSource
  *
  * This is a virtual method that should be implemented by subclasses.  It returns %TRUE
  * if drag and drop target support for the source should be activated.
diff --git a/sources/rb-library-source.c b/sources/rb-library-source.c
index 7abcdf6..24bc436 100644
--- a/sources/rb-library-source.c
+++ b/sources/rb-library-source.c
@@ -781,7 +781,7 @@ rb_library_source_format_changed_cb (GtkWidget *widget, RBLibrarySource *source)
 	layout_example_label_update (source);
 }
 
-/**
+/*
  * Perform magic on a path to make it safe.
  *
  * This will always replace '/' with '-', and optionally make the file name
@@ -1125,7 +1125,7 @@ rb_library_source_layout_filename_changed (GConfClient *client,
 	layout_example_label_update (source);
 }
 
-/**
+/*
  * Build the absolute filename for the specified track.
  *
  * The base path is the extern variable 'base_path', the format to use
diff --git a/sources/rb-missing-files-source.c b/sources/rb-missing-files-source.c
index 896223c..bd94c13 100644
--- a/sources/rb-missing-files-source.c
+++ b/sources/rb-missing-files-source.c
@@ -267,7 +267,7 @@ rb_missing_files_source_get_property (GObject *object,
  * it would be trivial to make it use any source type
  * that did file access checks for its contents.
  * 
- * Return value: the #RBMissingFiles source
+ * Return value: the #RBMissingFilesSource
  */
 RBSource *
 rb_missing_files_source_new (RBShell *shell,
diff --git a/sources/rb-podcast-source.c b/sources/rb-podcast-source.c
index 55c96d3..383a0e2 100644
--- a/sources/rb-podcast-source.c
+++ b/sources/rb-podcast-source.c
@@ -26,7 +26,7 @@
  *
  */
 
-/**
+/*
  * SECTION:rb-podcast-source
  * @short_description: source displaying podcast feeds and episodes
  *
@@ -818,7 +818,7 @@ rb_podcast_source_get_property (GObject *object,
 	}
 }
 
-/**
+/*
  * rb_podcast_source_new:
  * @shell: the #RBShell instance
  *
@@ -1271,7 +1271,7 @@ posts_view_drag_data_received_cb (GtkWidget *widget,
 	impl_receive_drag (RB_SOURCE (source), selection_data);
 }
 
-/**
+/*
  * rb_podcast_source_add_feed:
  * @source: the #RBPodcastSource
  * @uri: the new feed to add
diff --git a/widgets/rb-entry-view.c b/widgets/rb-entry-view.c
index f8e3a20..181cd78 100644
--- a/widgets/rb-entry-view.c
+++ b/widgets/rb-entry-view.c
@@ -68,6 +68,8 @@
  * @RB_ENTRY_VIEW_COL_FIRST_SEEN: the first seen (imported) column
  * @RB_ENTRY_VIEW_COL_LAST_SEEN: the last seen column
  * @RB_ENTRY_VIEW_COL_LOCATION: the location column
+ * @RB_ENTRY_VIEW_COL_BPM: the BPM column
+ * @RB_ENTRY_VIEW_COL_COMMENT: the comment column
  * @RB_ENTRY_VIEW_COL_ERROR: the error column
  *
  * Predefined column types to use in #RBEntryView<!-- -->s.  Use
@@ -1296,7 +1298,7 @@ rb_entry_view_get_sorting_order (RBEntryView *view,
  * rb_entry_view_set_sorting_order:
  * @view: a #RBEntryView
  * @column_name: name of the column to sort on
- * @sort_order: order to sort in, as a #GtkSortOrder
+ * @sort_order: order to sort in, as a #GtkSortType
  *
  * Sets the sort order for the entry view.
  */
diff --git a/widgets/rb-property-view.c b/widgets/rb-property-view.c
index 9bdcde6..553828b 100644
--- a/widgets/rb-property-view.c
+++ b/widgets/rb-property-view.c
@@ -185,7 +185,7 @@ rb_property_view_class_init (RBPropertyViewClass *klass)
 	/**
 	 * RBPropertyView:property-model:
 	 *
-	 * The #RhythmDBProperyModel backing the view.
+	 * The #RhythmDBPropertyModel backing the view.
 	 */
 	g_object_class_install_property (object_class,
 					 PROP_MODEL,



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/rhythmdb/rhythmdb.c b/rhythmdb/rhythmdb.c
index 29cec30..a4a0655 100644
--- a/rhythmdb/rhythmdb.c
+++ b/rhythmdb/rhythmdb.c
@@ -3987,7 +3987,7 @@ rhythmdb_entry_count (RhythmDB *db)
 
 /**
  * rhythmdb_entry_foreach_by_type:
- * @db: a #RhythmdB.
+ * @db: a #RhythmDB.
  * @entry_type: the type of entry to retrieve
  * @func: the function to call with each entry
  * @data: user data to pass to the function.
@@ -4608,25 +4608,25 @@ rhythmdb_compute_status_normal (gint n_songs,
 /**
  * rhythmdb_register_entry_type:
  * @db: the #RhythmDB
  * @etype: the new entry type to register
  *
  * Registers a new entry type.  An entry type must be registered before
  * any entries can be created for it.
  */
 void
-rhythmdb_register_entry_type (RhythmDB *db, RhythmDBEntryType *etype)
+rhythmdb_register_entry_type (RhythmDB *db, RhythmDBEntryType *entry_type)
 {
 	RhythmDBClass *klass = RHYTHMDB_GET_CLASS (db);
 	char *name = NULL;
 
-	g_object_get (etype, "name", &name, NULL);
+	g_object_get (entry_type, "name", &name, NULL);
 	g_assert (name != NULL);
 	g_mutex_lock (db->priv->entry_type_map_mutex);
-	g_hash_table_insert (db->priv->entry_type_map, name, g_object_ref (etype));
+	g_hash_table_insert (db->priv->entry_type_map, name, g_object_ref (entry_type));
 	g_mutex_unlock (db->priv->entry_type_map_mutex);
 
 	if (klass->impl_entry_type_registered)
-		klass->impl_entry_type_registered (db, etype);
+		klass->impl_entry_type_registered (db, entry_type);
 }
 
 /**
@@ -4608,25 +4608,25 @@ rhythmdb_compute_status_normal (gint n_songs,
  * rhythmdb_register_entry_type:
  * @db: the #RhythmDB
- * @etype: the new entry type to register
+ * @entry_type: the new entry type to register
  *
  * Registers a new entry type.  An entry type must be registered before
diff --git a/shell/rb-shell.c b/shell/rb-shell.c
index 27c308c..b3db3a6 100644
--- a/shell/rb-shell.c
+++ b/shell/rb-shell.c
@@ -32,7 +32,7 @@
  * @short_description: holds the Rhythmbox main window and everything else
  *
  * RBShell is the main application class in Rhythmbox.  It creates and holds
  * references to the other main objects (#RBShellPlayer, #RhythmDB, #RBSourcelist),
  * constructs the main window UI, and provides the basic DBus interface.
  */
 
@@ -675,13 +675,13 @@ rb_shell_class_init (RBShellClass *klass)
 	/**
 	 * RBShell:sourcelist:
 	 *
-	 * The #RBSourcelist instance
+	 * The #RBSourceList instance
 	 */
 	g_object_class_install_property (object_class,
 					 PROP_SOURCELIST,
 					 g_param_spec_object ("sourcelist",
 							      "sourcelist",
-							      "RBSourcelist",
+							      "RBSourceList",
 							      RB_TYPE_SOURCELIST,
 							      G_PARAM_READABLE));
 
@@ -32,7 +32,7 @@
  *
  * RBShell is the main application class in Rhythmbox.  It creates and holds
- * references to the other main objects (#RBShellPlayer, #RhythmDB, #RBSourcelist),
+ * references to the other main objects (#RBShellPlayer, #RhythmDB, #RBSourceList),
  * constructs the main window UI, and provides the basic DBus interface.
  */